@@ -34,7 +34,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- $Id: broyden.c 2067 2012-07-27 20:59:32Z beerli $
+ $Id: broyden.c 2139 2013-03-03 22:13:06Z beerli $
 started 1996
 -------------------------------------------------------*/
 /*! \file broyden.c
@@ -2164,8 +2164,9 @@ MYREAL normal_func_ok(MYREAL *param, MYREAL *param0, long numpop2)
     {
         if(param0[i]>0.0)
         {
-            diff = param[i]-(p0=param0[i]);
-            result += -(diff*diff/(2. * p0 *p0)) - 0.91893853320467274178 - log(p0);
+	  p0=param0[i];
+	  diff = param[i]-p0;
+	  result += -(diff*diff/(2. * p0 *p0)) - 0.91893853320467274178 - log(p0);
         }
     }
     return result;
