@@ -31,7 +31,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: data.c 2078 2012-08-19 19:03:55Z beerli $
+$Id: data.c 2127 2013-01-30 10:13:45Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -65,6 +65,7 @@ Data manipulation routines
 #endif
 extern long number_genomes (int type);
 extern void jumble (long *s, long n);
+extern void jumble_ownseed (long *s, long n);
 
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
@@ -110,7 +111,7 @@ void print_seqdata (world_fmt * world, option_fmt * options, data_fmt * data);
 
 void print_header (FILE * outfile, long pop, world_fmt * world,
                    option_fmt * options, data_fmt * data);
-void create_alleles (data_fmt * data, option_fmt *options);
+MYREAL create_alleles (data_fmt * data, option_fmt *options);
 void addAllele (data_fmt * data, char s[], long locus, long *z);
 void set_numind (data_fmt * data);
 void print_seq_pop (long locus, long pop, world_fmt * world,
@@ -164,6 +165,7 @@ destroy_data (data_fmt * data)
   myfree(data->subloci);
   myfree(data->maxalleles);
   myfree(data->skiploci);
+  myfree(data->locusweight);
 
   // free data from init_data_structure2
   for(pop=0; pop < numpop ; pop++)
@@ -224,16 +226,22 @@ destroy_data (data_fmt * data)
  
 ///
 /// shuffles (jumbles) the individuals so that we can take the first y to subsample the dataset
-void shuffle(long **shuffled, long n, boolean shuffle_ON)
+void shuffle(long **shuffled, long n, int shuffle_ON)
 {
   long i;
   for(i=0;i<n;i++)
     {
       (*shuffled)[i] = i;
     }
-  if(shuffle_ON)
+  switch(shuffle_ON)
     {
-        jumble (*shuffled, n);
+    case 0:
+      break;
+    case -1:
+      jumble(*shuffled, n);
+      break;
+    default:
+      jumble_ownseed(*shuffled, n);
     }
 }
 
@@ -250,11 +258,11 @@ void shuffle_data(data_fmt *data, option_fmt *options)
 	  data->shuffled[pop][locus] = (long *) mycalloc(data->numind[pop][locus], sizeof(long));
 	  if(options->randomsubset>0 && options->randomsubset <  data->numind[pop][locus])
 	    {	
-	      shuffle(&data->shuffled[pop][locus],data->numind[pop][locus],TRUE);
+	      shuffle(&data->shuffled[pop][locus],data->numind[pop][locus],options->randomsubsetseed);
 	    }
 	  else
 	    {
-	      shuffle(&data->shuffled[pop][locus],data->numind[pop][locus],FALSE);
+	      shuffle(&data->shuffled[pop][locus],data->numind[pop][locus],0);
 	    }
 	}
     }
@@ -291,8 +299,11 @@ void
 get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world)
 {
   //long locus;
+  MYREAL mean;
   long pop;
+  long locus;
   long genomes=1;
+  boolean saved_option_murate=FALSE;
   data->hasghost = FALSE;
   // read how many populations and loci and delimiter and title
   // if we have the new haplotype input then there should be no delimiter
@@ -335,27 +346,31 @@ get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *w
     if (options->progress)
         fprintf (stdout, "\n\n");
     init_data_structure3 (data,options);
-
+    if ((options->onlyvariable || options->has_variableandone) && !options->murates_fromdata)
+      {
+	saved_option_murate = TRUE;
+	options->murates_fromdata = TRUE;
+      }
     switch (options->datatype)
     {
     case 'a':
-        create_alleles (data, options);
+        mean = create_alleles (data, options);
         break;
     case 'b':
-        create_alleles (data, options);
+        mean = create_alleles (data, options);
         for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = XBROWN_SIZE;
         break;
     case 'm':
-        create_alleles (data, options);
+        mean = create_alleles (data, options);
         for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = options->micro_stepnum;
         break;
     case 'h':
     case 'n':
     case 'u':
-        create_alleles (data, options);
-        break;
+      mean = create_alleles (data, options);
+      break;
     default: /*DNA types*/
       for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = 4;
@@ -367,8 +382,21 @@ get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *w
       {
 	if (strchr (SEQUENCETYPES, options->datatype))
 	  {
-	    find_rates_fromdata(data, options);
+	    find_rates_fromdata(data, options, world);
 	  }
+	else
+	  {
+	    find_rates_fromdata_alleles(data, options, world, mean);
+	  }
+      }
+    if(saved_option_murate)
+      {
+	for (locus=0; locus < data->loci; locus++)
+	  {
+	    options->mu_rates[locus] = 1.0;
+	  }
+	options->murates_fromdata=FALSE;
+	saved_option_murate = FALSE;
       }
 }
 
@@ -376,8 +404,10 @@ void
 get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world)
 {
   long locus;
-    long pop;
-    long genomes=1;
+  long pop;
+  long genomes=1;
+  MYREAL mean;
+  boolean saved_option_murate=FALSE;
     data->hasghost = FALSE;
     read_header (infile, data, options);
     genomes =  number_genomes (options->datatype);
@@ -431,27 +461,31 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world
     if (options->progress)
         fprintf (stdout, "\n\n");
     init_data_structure3 (data,options);
-
+    if ((options->onlyvariable || options->has_variableandone) && !options->murates_fromdata)
+      {
+	saved_option_murate = TRUE;
+	options->murates_fromdata = TRUE;
+      }
     switch (options->datatype)
     {
     case 'a':
-        create_alleles (data, options);
+        mean=create_alleles (data, options);
         break;
     case 'b':
-        create_alleles (data, options);
+        mean=create_alleles (data, options);
         for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = XBROWN_SIZE;
         break;
     case 'm':
-        create_alleles (data, options);
+        mean=create_alleles (data, options);
         for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = options->micro_stepnum;
         break;
     case 'h':
     case 'n':
     case 'u':
-        create_alleles (data, options);
-        break;
+      mean=create_alleles (data, options);
+      break;
     default: /*DNA types*/
       for (pop = 0; pop < data->loci; pop++)
             data->maxalleles[pop] = 4;
@@ -463,8 +497,21 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world
       {
 	if (strchr (SEQUENCETYPES, options->datatype))
 	  {
-	    find_rates_fromdata(data, options);
+	    find_rates_fromdata(data, options, world);
 	  }
+	else
+	  {
+	    find_rates_fromdata_alleles(data, options, world, mean);
+	  }
+      }
+    if(saved_option_murate)
+      {
+	for (locus=0; locus < data->loci; locus++)
+	  {
+	    options->mu_rates[locus] = 1.0;
+	  }
+	options->murates_fromdata=FALSE;
+	saved_option_murate = FALSE;
       }
 }
 
@@ -538,7 +585,9 @@ init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
 
     (*data)->yy[pop] = (char ****) mymalloc (sizeof (char ***) * indalloc);
     (*data)->indnames[pop] = (char ***) mycalloc (1, sizeof (char **) * indalloc);
+#ifdef DEBUG 
     printf("init_data_structure2: indalloc=%li\n",indalloc);
+#endif
     for (ind = 0; ind < indalloc; ind++)
     {
         (*data)->indnames[pop][ind] =
@@ -628,6 +677,12 @@ init_data_structure3 (data_fmt * data, option_fmt *options)
     data->maxalleles = (long *) mycalloc (1, sizeof (long) * data->loci);
     data->skiploci =
         (boolean *) mycalloc (1, sizeof (boolean) * (data->loci + 1));
+    data->locusweight =
+        (MYREAL *) mycalloc (1, sizeof (MYREAL) * (data->loci + 1));
+    for (locus=0;locus < data->loci; locus++)
+      {
+	data->locusweight[locus]=1.0;
+      }
 }
 
 ///
@@ -1150,7 +1205,7 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
 		  {
 		    minlength = strlen(input);
 		    minlength = MIN(minlength,80);
-		    strncpy(data->popnames[pop],input,minlength);
+		    sprintf(data->popnames[pop],"%-*s",(int) minlength,input);
 		  }
                 break;//this leaves the numind empty of not specified, the must be filled in later
 	      }
@@ -1164,7 +1219,7 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
                 FGETS(input,LINESIZE,infile);
 		minlength = strlen(input);
 		minlength = MIN(minlength,80);
-		strncpy(data->popnames[pop],input,minlength);
+		sprintf(data->popnames[pop],"%-*s", (int) minlength, input);
 	      }
 	  }
 	
@@ -1362,8 +1417,8 @@ read_microalleles (FILE * infile, data_fmt * data, option_fmt *options, long pop
         {
             strcpy (a2, a1);
         }
-        strncpy (data->yy[pop][ind][locus][0], a1, options->allelenmlength);
-        strncpy (data->yy[pop][ind][locus][1], a2, options->allelenmlength);
+        sprintf (data->yy[pop][ind][locus][0], "%-.*s",(int) options->allelenmlength,a1);
+        sprintf (data->yy[pop][ind][locus][1], "%-.*s",(int) options->allelenmlength,a2);
     }
     myfree(a);
     myfree(a1);
@@ -1885,6 +1940,7 @@ void print_random_subset(FILE * file, data_fmt * data, option_fmt *options)
   long count;
   long ind;
   long length;
+  long index;
   if(options->randomsubset > 0)
     {
       fprintf (file, "\nData set was subsampled and used a random sample of size: %li\n\n", options->randomsubset);
@@ -1901,12 +1957,12 @@ void print_random_subset(FILE * file, data_fmt * data, option_fmt *options)
 	      count = 18;
 	      for(ind=0;ind<maxnum;ind++)
 		{
-		  //long index = data->shuffled[pop][locus][ind];
+		  index = data->shuffled[pop][locus][ind];
 
-		  if(data->indnames[pop][ind][locus][0]=='\0')
-		    memcpy(name,data->indnames[pop][ind][0],sizeof(char)*options->nmlength);
+		  if(data->indnames[pop][index][locus][0]=='\0')
+		    memcpy(name,data->indnames[pop][index][0],sizeof(char)*options->nmlength);
 		  else
-		    memcpy(name,data->indnames[pop][ind][locus],sizeof(char)*options->nmlength);
+		    memcpy(name,data->indnames[pop][index][locus],sizeof(char)*options->nmlength);
 		  remove_trailing_blanks(&name);
 		  length = strlen(name);
 		  if (count+length < LINELENGTH)
@@ -2132,6 +2188,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   MYREAL general_homo;
   FILE *outfile = world->outfile;
   long loctotal;
+  long t;
   boolean second = (strchr(ALLELETYPES,options->datatype)!=NULL);
   if (strchr (DNASEQUENCETYPES, options->datatype))
     return; /*we do not calculate allele frequencies for DNA sequences*/
@@ -2218,10 +2275,12 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 	continue;
       for (locus = 0; locus < data->loci; locus++)
 	{
+	  //accumulate the pooled populations frequencies
 	  for(a=0; a < maxalleles[locus]; a++)
 	    {
 	      freq[pop][locus][a] += freq[pop1][locus][a];
 	    }
+	  //replace all locations frequencies with the population freq
 	  for(a=0; a < maxalleles[locus]; a++)
 	    {
 	      freq[pop1][locus][a] = freq[pop][locus][a];
@@ -2252,7 +2311,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   for (locus = 0; locus < data->loci; locus++)
     {
       fprintf(outfile,"Locus %li\n", locus + 1);
-      fprintf(outfile,"Allele  ");
+      fprintf(outfile,"Allele      ");
       general_homo = 0.0;
       for (pop1 = 0; pop1 < data->numpop; pop1++)
 	{
@@ -2260,14 +2319,17 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 	  pop = options->newpops[pop1]-1;
 	  fprintf(outfile,"Pop%-2li  ",pop+1);
 	}
-      fprintf(outfile,"All\n-------");
+      fprintf(outfile,"All\n-----------");
       for (pop = 0; pop < data->numpop+1; pop++)
 	fprintf(outfile,"-------");
       fprintf(outfile, "\n");
       for(a=0; a < maxalleles[locus]; a++)
 	{
 	  allfreq = 0.0;
-	  fprintf(outfile,"%6s ",data->allele[locus][a]);
+	  if(strlen(data->allele[locus][a])>8)
+	    fprintf(outfile,"%-8.8s...",data->allele[locus][a]);
+	  else
+	    fprintf(outfile,"%-8.8s   ",data->allele[locus][a]);
 	  for (pop1 = 0; pop1 < data->numpop; pop1++)
 	    {
 	      pop = options->newpops[pop1]-1;
@@ -2293,20 +2355,26 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 	  world->mutationmodels[world->sublocistarts[locus]].basefreqs[a] = allfreq/data->numpop;
 #endif
 	}
-      fprintf(outfile,"Total  ");
+      fprintf(outfile,"Alleles    ");
       for (pop1 = 0; pop1 < data->numpop; pop1++)
 	{
 	  // pop = options->newpops[pop1]-1;
 	  fprintf(outfile," %5li ",  maxallelepop[pop1]);
 	}
       fprintf(outfile," %5li\n", maxalleles[locus]);
-
-      if(maxalleles[locus]<=1 && strchr(SNPTYPES,options->datatype))
+      fprintf(outfile,"Samplesize ");
+      for (pop1 = 0; pop1 < data->numpop; pop1++)
 	{
-	  data->skiploci[locus] = TRUE;
+	  fprintf(outfile," %5li ",  (long) total[pop1][locus]);
 	}
+      fprintf(outfile," %5li\n", (long) grandtotal[locus]);
 
-      fprintf(outfile,"H_exp  ");
+      //if(maxalleles[locus]<=1 && strchr(SNPTYPES,options->datatype))
+      //{
+      //  data->skiploci[locus] = TRUE;
+      //}
+
+      fprintf(outfile,"H_exp      ");
       for (pop1 = 0; pop1 < data->numpop; pop1++)
 	{
 	  pop = options->newpops[pop1]-1;
@@ -2456,7 +2524,6 @@ print_header (FILE * outfile, long pop, world_fmt * world,
 {
     long i;
     long locus, mult80 = 80;
-    char input[LINESIZE];
     fprintf (outfile, "\n%-s", data->popnames[pop]);
     for (i = 0; i < (long) (80 - (long) strlen (data->popnames[pop])); i++)
          fprintf(world->outfile, "-");
@@ -2477,8 +2544,7 @@ print_header (FILE * outfile, long pop, world_fmt * world,
             }
             fprintf (outfile, "  %2li", locus + 1);
         }
-        fprintf (outfile, "\n%-s\n",
-                 strncpy (input, "indiv.", options->nmlength));
+        fprintf (outfile, "\n%-*.*s\n", (int) options->nmlength, (int) options->nmlength, "indiv.");
     }
 }
 
@@ -2613,7 +2679,7 @@ void find_allele_repeatlength(data_fmt *data, option_fmt *options, long locus)
 }
 
 
-void
+MYREAL
 create_alleles (data_fmt * data, option_fmt *options)
 {
   long n=0;
@@ -2656,7 +2722,7 @@ create_alleles (data_fmt * data, option_fmt *options)
         }
 	if(z==0)
 	  {
-	    data->skiploci[locus] = TRUE;
+	    data->skiploci[locus] = TRUE;// this skips loci with _no_ data
 	    continue;
 	  }
 
@@ -2684,6 +2750,7 @@ create_alleles (data_fmt * data, option_fmt *options)
 	      options->mu_rates[locus] /= mean;
 	  }
       }
+    return mean;
 }
 
 void
