@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c 1800 2011-01-29 13:40:00Z beerli $
+$Id: lrt.c 2056 2012-06-14 02:38:30Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
@@ -105,7 +105,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
         FPRINTF (stdout, "           Printing likelihood ratio tests\n");
 
     nr = (nr_fmt *) mycalloc (1, sizeof (nr_fmt));
-    create_nr (nr, world, *Gmax, 0, world->loci, world->repkind, world->rep);
+    create_nr (nr, world, *Gmax, 0L, world->loci, world->repkind, world->rep);
     for (locus = 0; locus < world->loci; locus++)
     {
         if (world->options->replicate)
@@ -135,7 +135,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
                     sizeof (MYREAL) * nparam);
             df = set_test_param (param0,
                                  &world->options->lratio->data[c],
-                                 world, 0, -1, maxwhich, &maxnum, &zeros);
+                                 world, 0L, -1L, maxwhich, &maxnum, &zeros);
             test_loci_like (nr, param0, param1,
                             df, zeros, world->loci, world, maxwhich,
                             maxnum, header,
@@ -244,7 +244,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
                  "==============================================================================\n");
         FPRINTF (world->outfile, "Over all loci\n");
         FPRINTF (world->outfile, "Legend for the LRT tables\n");
-        print_line(world->outfile,'-',79,CONT);
+        print_line(world->outfile,'-',79L,CONT);
         sprintf (temp,"Null-Hypothesis: your test model");
         FPRINTF(world->outfile,"%-*.*s | Log(likelihood) of test model\n",BOXSIZE2,BOXSIZE2,temp);
         sprintf (temp,"=same=");
@@ -261,7 +261,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
         FPRINTF(world->outfile,"%-*.*s | Akaike's Information Criterion***\n",BOXSIZE2,BOXSIZE2,temp);
         sprintf (temp," ");
         FPRINTF(world->outfile,"%-*.*s | Number of parameters used\n",BOXSIZE2,BOXSIZE2,temp);
-        print_line(world->outfile,'-',79,CONT);
+        print_line(world->outfile,'-',79L,CONT);
         FPRINTF(world->outfile,"  *) Probability under the assumption that parameters have range -Inf to Inf\n");
         FPRINTF(world->outfile," **) Probability under the assumption that parameters have range 0 to Inf\n");
         FPRINTF(world->outfile,"***) AIC: the smaller the value the better the model\n");
@@ -310,8 +310,8 @@ void print_lrt_box(world_fmt *world, MYREAL *param0, MYREAL *param1, long zeros,
     long i;
     
     if(world->options->progress)
-        print_line(stdout,'-',79,CONT);
-    print_line(world->outfile,'-',79,CONT);
+        print_line(stdout,'-',79L,CONT);
+    print_line(world->outfile,'-',79L,CONT);
     box = (char **) mycalloc (size, sizeof (char *));
     for(i=0; i<size; i++)
         box[i] = (char *) mycalloc(LRATIO_STRINGS,sizeof(char));
@@ -319,8 +319,8 @@ void print_lrt_box(world_fmt *world, MYREAL *param0, MYREAL *param1, long zeros,
     print_box(world,box,newsize,like0,like1,testval, chiprob, chiprob2, aic, df, aicparamnum);
     pdf_print_LRT_box(world,box,newsize,like0,like1,testval, chiprob, chiprob2, aic, df, aicparamnum, &world->page_height, & world->page_width);
     if(world->options->progress)
-        print_line(stdout,'-',79,CONT);
-    print_line(world->outfile,'-',79,CONT);
+        print_line(stdout,'-',79L,CONT);
+    print_line(world->outfile,'-',79L,CONT);
     for(i=0; i<size; i++)
         myfree(box[i]);
     myfree(box);
