@@ -18,7 +18,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: mcmc1.c 2056 2012-06-14 02:38:30Z beerli $
+ $Id: mcmc1.c 2139 2013-03-03 22:13:06Z beerli $
  -------------------------------------------------------*/
 /* \file mcmc1.c
  
@@ -1159,17 +1159,30 @@ migrate_old (proposal_fmt * proposal, node * up, long *old_migr_table_counter,
 long
 migration_from_old (long to, proposal_fmt * proposal)
 {
+  // not completely fixed for change if Nm tracking!!!! //@@
     long j, ii, msta, msto;
     MYREAL *geo = proposal->world->data->geo;
     MYREAL *r, rr = UNIF_RANDUM ();
+    boolean usem = proposal->world->options->usem;
     r = (MYREAL *) mycalloc (1, sizeof (MYREAL) * proposal->numpop);
     msta = mstart (to, proposal->numpop);
     msto = mend (to, proposal->numpop);
-    r[0] = proposal->param0[msta] * geo[msta];
-    for (j = 1, ii = msta + 1; ii < msto; j++, ii++)
-    {
-        r[j] = r[j - 1] + geo[ii] * proposal->param0[ii];
-    }
+    if (usem)
+      {
+	r[0] = proposal->param0[msta]/proposal->param0[to] * geo[msta];//@@
+	for (j = 1, ii = msta + 1; ii < msto; j++, ii++)
+	  {
+	    r[j] = r[j - 1] + geo[ii] * proposal->param0[ii]/proposal->param0[to];//@@
+	  }
+      }
+    else
+      {
+	r[0] = proposal->param0[msta] * geo[msta];
+	for (j = 1, ii = msta + 1; ii < msto; j++, ii++)
+	  {
+	    r[j] = r[j - 1] + geo[ii] * proposal->param0[ii];
+	  }
+      }
     ii = 0;
     while (rr > r[ii] / r[j - 1])
     {
@@ -1915,7 +1928,11 @@ prob_tree (world_fmt * world, timelist_fmt * tyme)
 {
     long j, pop;
     MYREAL mm, cc, ss = 0;
-    
+    long tlfrom;
+    boolean usem = world->options->usem;
+    MYREAL pk;
+    const MYREAL mu_rate = world->options->mu_rates[world->locus];
+    const MYREAL lmu_rate = world->options->lmu_rates[world->locus];
     tyme->tl[0].interval = tyme->tl[0].age;
     for (j = 1; j < tyme->T; j++)
     {
@@ -1927,15 +1944,18 @@ prob_tree (world_fmt * world, timelist_fmt * tyme)
         for (pop = 0; pop < world->numpop; pop++)
         {
             mm += tyme->tl[j].lineages[pop] * world->mig0list[pop];
-            cc +=
-            tyme->tl[j].lineages[pop] * (tyme->tl[j].lineages[pop] -
-                                         1) / world->param0[pop];
+            cc += tyme->tl[j].lineages[pop] * (tyme->tl[j].lineages[pop] -
+					       1) / (world->param0[pop] * mu_rate);
         }
         ss += -(tyme->tl[j].interval) * (mm + cc);
-        if (tyme->tl[j].from == tyme->tl[j].to)
-            ss += LOG2 - LOG (world->param0[tyme->tl[j].from]);
+	tlfrom = tyme->tl[j].from;
+        if (tlfrom == tyme->tl[j].to)
+            ss += LOG2 - LOG (world->param0[tlfrom]*mu_rate);
         else
-            ss += LOG (world->param0[tyme->tl[j].from]);
+	  { //@@
+	    pk = usem ? world->param0[tlfrom]/mu_rate : world->param0[tlfrom] /(mu_rate * world->param0[pop]); 
+            ss += LOG (pk);
+	  }
     }
     return ss;
 }
