@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 2100 2012-11-19 21:41:03Z beerli $
+  $Id: migration.h 2139 2013-03-03 22:13:06Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -285,6 +285,7 @@ typedef struct _data
   long **repeatnumbers;
   long *repeatlength;
   boolean has_repeats;
+  MYREAL *locusweight; //invariant loci treatment
 }
 data_fmt;
 
@@ -332,6 +333,7 @@ typedef struct _bayes
   MYREAL *maxparam; // maximal allowed parameter value
   MYREAL *meanparam; // mean values for expprior
   MYREAL *alphaparam; // alpha value for gamma
+  MYREAL *betaparam; // beta value for gamma
   // record all changes of parameters
   MYREAL *params;  // save for parameter vectors
   long allocparams; //number of allocated parameter vectors
@@ -360,6 +362,7 @@ typedef struct _bayes
   long linesize;
   long progresslinesize;
   long *mdimfilecount;
+  MYREAL *priors;
 }
 bayes_fmt;
 
@@ -371,6 +374,7 @@ typedef struct prior_fmt
   MYREAL std;
   MYREAL max;
   MYREAL delta;
+  MYREAL alpha;
   long   bins;
 } prior_fmt;
 
@@ -615,6 +619,12 @@ typedef struct _option
   boolean has_autotune;
   MYREAL autotune;
   long totalsites; //for snp data
+  MYREAL *wattersons;
+  long *segregs;
+  boolean onlyvariable;  // analyze only variable sequence loci
+  MYREAL locusweight;    // use a weight to calculate the invariant locus
+  boolean has_variableandone; // use only one invariant locus and reweight
+  long firstinvariant; // locus number of first invariant locus to reweight using locusweight
 }
 option_fmt;
 
@@ -976,6 +986,11 @@ typedef struct _worldoption
   boolean heatedswap_off;
   boolean has_autotune;
   MYREAL autotune;
+  boolean onlyvariable;  // analyze only variable sequence loci
+  MYREAL locusweight;    // use a weight to calculate the invariant locus
+  boolean has_variableandone; // use only one invariant locus and reweight
+  long firstinvariant; // locus number of first invariant locus to reweight using locusweight
+
 }
 worldoption_fmt;
 
@@ -1007,7 +1022,7 @@ typedef struct _worlddata
 
     long uepsites;
 #endif
-
+  MYREAL *locusweight; //invariant loci treatment
 }
 worlddata_fmt;
 
@@ -1226,6 +1241,9 @@ typedef struct _world
   char * warning;
   long warningsize;
   long warningallocsize;
+  long maxreplicate;
+  long *accept_archive;
+  long *trials_archive;
 }
 world_fmt;
 
