@@ -21,7 +21,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2009 Peter Beerli, Tallahassee FL
  
-$Id: options.h 1546 2009-06-01 16:01:52Z beerli $
+$Id: options.h 1576 2009-09-09 18:22:38Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -138,6 +138,9 @@ void resynchronize_param (world_fmt * world);
 /// \param data  {holds all data related parts}
 /// \returns {None}
 void reorder_populations(world_fmt *world, option_fmt *options, data_fmt *data);
+/// 
+/// fills the option->newposts array with localities to reorder 
+void set_localities(char **value, char **tmp, option_fmt *options);
 ///
 /// sets the average of the mutation rates among loci and updates option structures
 /// in world->options and options.
