@@ -32,7 +32,7 @@ extern void pdf_print_end_time(float *page_height);
 // print options onto the first page
 extern void pdf_print_options(world_fmt * world, option_fmt *options, data_fmt * data, 
 			      float *orig_page_height, float *orig_left_margin);
-
+extern void pdf_print_mutationrate_weights(MYREAL *murates, long *segregs, MYREAL *wattersons, long loci);
 // DATA
 // print data summary
 extern void pdf_print_data_summary(world_fmt * world, option_fmt *options, data_fmt * data, 
@@ -48,8 +48,8 @@ extern void pdf_print_averageheat(world_fmt **universe, option_fmt *options);
 // print bayes table
 extern void pdf_print_bayestable(world_fmt *world);
 // print histogram at location lx ly with widht and height
-extern void pdf_histogram(MYREAL *binvals, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, boolean nofreq);
-extern void pdf_histogram_plus(MYREAL *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence, long topop);
+extern void pdf_histogram(float *binvals, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, boolean nofreq, MYREAL *priors);
+extern void pdf_histogram_plus(float *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence, long topop);
 // print histogram for each locus and overall loci
 extern float pdf_loci_histogram(world_fmt *world);
 // print acceptance ratios
