@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 2107 2012-12-11 16:00:42Z beerli $
+$Id: random.c 2135 2013-02-18 19:55:44Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include <stdlib.h>
@@ -69,6 +69,8 @@ long random_integer(long low, long high);
 #ifdef QUASIRANDOM
 #define MYINDEX 0
 
+//char[100] generator;
+
 #ifdef CUD
 int  nextn=1, kk=1,ii=0,jj=0;
 void setup_cud(int thiskk)
@@ -571,7 +573,7 @@ void getseed(option_fmt *options)
       getseed_lcg(options);
 #endif
       if(options->progress)
-	printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
+	printf("Master random number seed: %li\n", options->inseed);
       newseeds = (long*) calloc(numcpu,sizeof(long));
       for (worker=1;worker<numcpu;worker++)
 	{
@@ -670,12 +672,12 @@ void getseed(option_fmt *options)
 #ifdef DEBUG
       char nowstr[LINESIZE];
       get_time (nowstr, "%c");
-      printf("%i> RANDOM NUMBER SEED:%li at time %s\n",myID,test,nowstr);
+      printf("%i> Random number seed: %li at time %s\n",myID,test,nowstr);
 #endif
     }
   else
     {
-      printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
+      printf("%i> Master random number seed: %li\n",myID,options->inseed);
     }
 }
 #endif /*0*/
