@@ -16,7 +16,7 @@ Copyright 2003-2012 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 2127 2013-01-30 10:13:45Z beerli $
+$Id: reporter.c 2144 2013-03-12 03:14:13Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -1197,11 +1197,11 @@ chain_means_bayes (MYREAL *thischainmeans, world_fmt * world)
 void
 chain_means (MYREAL *thischainmeans, world_fmt * world)
 {
-  MYREAL temp;
+  float temp;
 
   if(world->options->bayes_infer)
     {
-      temp = (world->convergence->chain_counts[world->rep]!=0) ? world->convergence->chain_counts[world->rep] : 1;  
+      temp = (float) (world->convergence->chain_counts[world->rep]!=0) ? world->convergence->chain_counts[world->rep] : 1;  
       world->convergence->chain_counts[world->rep] = temp;
       chain_means_bayes (thischainmeans, world);
     }
