@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 2120 2013-01-03 05:17:21Z beerli $
+ $Id: sequence.c 2145 2013-03-12 03:18:48Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -2082,7 +2082,7 @@ void find_rates_fromdata_alleles(data_fmt * data, option_fmt * options, world_fm
   options->segregs = (long *) mycalloc(data->loci, sizeof(long));
   for (locus=0;locus < data->loci; locus++)
     {
-      options->segregs[locus] = lround(options->mu_rates[locus] *  mean);
+      options->segregs[locus] = (long) (options->mu_rates[locus] *  mean + 0.5);
     }
 }
 
