@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 2078 2012-08-19 19:03:55Z beerli $
+$Id: tools.c 2139 2013-03-03 22:13:06Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -375,7 +375,7 @@ void onepass_mean_std_end(MYREAL *mean, MYREAL *std, long *n)
 {
   (*std) = sqrt((*std) / ((*n) - 1));
 }
-
+#ifndef PRIORTEST
 /*garbage collection and recycle*/
 #ifdef MESS
 boolean find_in_list(long id)
@@ -1172,7 +1172,7 @@ znzopenfile (znzFile * fp, char *filename, char *mode, int use_compressed)
     if ((p = strpbrk (filename, CRLF)) != NULL)
         *p = '\0';
     remove_trailing_blanks(&filename);
-    strncpy (file, filename, LINESIZE - 1);
+    sprintf(file, "%-.*s", (int) LINESIZE, filename);
     of = znzopen (file, mode,use_compressed);
     if (znz_isnull(of))
       error("Could not open zipped bayesallfile");
@@ -1197,7 +1197,7 @@ openfile (FILE ** fp, char *filename, char *mode, char *perm)
     if ((p = strpbrk (filename, CRLF)) != NULL)
         *p = '\0';
     remove_trailing_blanks(&filename);
-    strncpy (file, filename, LINESIZE - 1);
+    sprintf(file, "%-.*s",(int) LINESIZE, filename);
 #ifdef CAUTIOUS
     if(cautious)
       {
@@ -1298,6 +1298,22 @@ openfile (FILE ** fp, char *filename, char *mode, char *perm)
     myfree(file);
 }
 
+void get_filename(char **store, char * value)
+{
+  long ls;
+  long lv;
+  remove_trailing_blanks(&value);
+  ls = strlen(*store)+1;
+  lv = strlen(value)+1;
+      if (ls < lv)
+	{
+	  (*store) = (char *) realloc(*store,sizeof(char)*lv);
+	  memset(*store,0,sizeof(char)*lv);
+	}
+      strcpy (*store, value);
+}
+
+
 long
 read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 {
@@ -1794,7 +1810,7 @@ children (node * mother, node ** brother, node ** sister)
         (*sister) = crawlback (m->next->next);
     }
 }
-
+#endif /*not PRIORTEST*/
 /*       Uses Lanczos-type approximation to ln(gamma) for z > 0. */
 /*       Reference: */
 /*            Lanczos, C. 'A precision approximation of the gamma */
@@ -1829,7 +1845,7 @@ mylgamma (MYREAL z)
         tmp -= 1.;
     }
     result += a[0];
-    result = LOG (result) + lnsqrt2pi - (z + 6.5) + (z - 0.5) * LOG (z + 6.5);
+    result = log (result) + lnsqrt2pi - (z + 6.5) + (z - 0.5) * log (z + 6.5);
     return result;
 }    /* lgamma */
 
@@ -3052,13 +3068,15 @@ chisquare (long df, MYREAL alpha)
         {
             6.63490, 9.21034, 11.3449, 13.2767, 15.0863, 16.8119
         };
-
-    if (alpha == 0.05)
-        return table05[df - 1];
-    if (alpha == 0.01)
-        return table01[df - 1];
-    error ("Chi-distribution for any probability alpha is not implemented");
-    return -1;
+    if( df<=6)
+      {
+	if (alpha == 0.05)
+	  return table05[df - 1];
+	if (alpha == 0.01)
+	  return table01[df - 1];
+      }
+    return -100000000;
+    //    return generalized_gamma(0.5,df/2.0,1.0,alpha);
 }
 
 MYREAL
@@ -3215,13 +3233,14 @@ m2mml2 (long i, long topop, long numpop)
     }
 }
 
+#ifndef PRIORTEST
 void  set_paramstr(char *paramstr, long j, long numpop, boolean usem)
 {
   long frompop;
   long topop;
   const long numpop2 = numpop * numpop;
   if (j < numpop)
-    sprintf(paramstr,"Theta_%3li",j+1);
+    sprintf(paramstr,"Theta_%-3li",j+1);
   else
     {
       if (j < numpop2)
@@ -3615,7 +3634,7 @@ boolean shortcut(long j0,bayes_fmt *bayes, long *j)
       return FALSE;
     }
 }
-
+#endif
 
 // calculates a rough approximation to log(val)
 // max error = 0.0007
