@@ -26,7 +26,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
 
-$Id: world.h 2040 2012-05-31 19:32:14Z beerli $
+$Id: world.h 2139 2013-03-03 22:13:06Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -47,6 +47,8 @@ extern void print_menu_coalnodes (FILE * file, world_fmt * world, long G,
                                       long rep);
 extern void print_progress(worldoption_fmt * options, world_fmt * world,
                long rep, long visited, long accepted);
+extern void print_fst (world_fmt * world, option_fmt * options,
+                data_fmt * data, MYREAL **fstparam);
 extern void burnin_chain (world_fmt * world);
 extern void print_finish (world_fmt * world, long filepos);
 extern void copy_time (world_fmt * world, timelist_fmt * ltl, long from,
